@@ -4,7 +4,7 @@ import shutil
 from datetime import datetime
 
 from python_search.configuration.configuration import PythonSearchConfiguration
-from python_search.events.run_performed import RunPerformed
+from python_search.events.run_performed import EntryExecuted
 
 
 class FilesystemEntryInserter:
@@ -22,7 +22,6 @@ class FilesystemEntryInserter:
         self._new_entries_string = FilesystemEntryInserter.NEW_ENTRIES_STRING
 
     def insert(self, key: str, entry: dict):
-
         entry["created_at"] = datetime.now().isoformat()
 
         if "tags" in entry and self._configuration.tags_dependent_inserter_marks:
@@ -43,8 +42,8 @@ class FilesystemEntryInserter:
 
         from python_search.events.run_performed.writer import LogRunPerformedClient
 
-        LogRunPerformedClient().send(
-            RunPerformed(key=key, query_input="", shortcut=False)
+        LogRunPerformedClient(self._configuration).send(
+            EntryExecuted(key=key, query_input="", shortcut=False)
         )
 
         from python_search.apps.notification_ui import send_notification
