@@ -3,7 +3,6 @@ from concurrent.futures import ThreadPoolExecutor
 
 
 class Focus:
-
     def focus_register_new(self):
         result = os.system("""
         osascript -e 'tell application "System Events" to tell process "python3"
@@ -15,6 +14,23 @@ end tell'
 
         return True if result == 0 else False
 
+
+    def focus_window(self, app, title):
+        cmd = f"""
+        osascript -e '
+        tell application "System Events"
+            tell application process "{app}"		
+                perform action "AXRaise" of (first window whose name contains "{title}")
+                set frontmost to true
+            end tell
+        end tell
+        ' 
+            """
+        result = os.system(cmd)
+        print(f" trying to focus {result}")
+
+        return True if result == 0 else False
+
     def async_focus_register_new(self):
         with ThreadPoolExecutor(max_workers=1) as executor:
             future = executor.submit(self.focus_register_new)
